#!/bin/bash
###############################################################################
#
# checkFieldinDicom.sh 
# Purpose:	given a tag, in the format, xxxx,yyyy, and a value, surrounded
#		by quotes if it has spaces, returns the list of styiuids in the eRAD
#		archive having that value in that tag.  This program creates at least 
#		two files:
#			1.  File containing STYIUIDs of matching studies - Matches.stys
#			2.  File containing STYIUIDs and non matching values - NonMatching.info
# Author:	Tony Bowles
# Date:		Jan 26, 2009
#
###############################################################################
. $HOME/etc/setenv.sh

E_OPTERROR=65
STUDYLIST="archivedstys.ls"

###############################################################################
# Defaults
###############################################################################
MatchingFile="Matches.stys"
NonMatchingFile="NonMatching.info"

###############################################################################
# Functions
###############################################################################
function usage()
{
	echo -e "\n"
	echo -e "	Given a tag, in the format, xxxx,yyyy, and a value, surrounded"
	echo -e "	by quotes if it has spaces, returns the list of styiuids in the eRAD"
	echo -e "	archive having that value in that tag.  This program creates at least "
	echo -e "	two files:"
	echo -e "		1.  File containing STYIUIDs of matching studies - Matches.stys"
	echo -e "		2.  File containing STYIUIDs and non matching values - NonMatching.info\n"
	echo -e "\nUSAGE:\n"
	echo -e "\t$0 -t tag -v value [-h] [-m MatchingFileName] [-n Non-MatchingFileName]"
	echo -e "\n\t-t\tTag value to search for. Expected format: xxxx,yyyy"
	echo -e "\t-v\tValue to look for in tag.  Should be in enclosed in \" \" if value has spaces"
	echo -e "\t-m\tName to use for Matching study output file.  Default value is $MatchingFile"
	echo -e "\t-n\tName to use for Non-Matching study output file.  Default value is $NonMatchingFile"
	echo -e "\t-h\tDisplay this usage and exit."
	echo -e "\n"
}

function checktag()
{
	local ptag="$1"
    rc=`echo $ptag | grep "^[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F],[0-9a-fA-F][0-9a-fA-F][0-9a-fA-F][0-9a-fA-F]$"`
    if [ "$rc" = "" ] ; then
		echo -e "\nERROR: Tag format check failed.  Ensure tag is in format XXXX,YYYY.\n"
		exit
	fi
}

function getObject()
{
	local sty="$1"
    adir=`/home/image/tools/q_archiveloc.sh $sty`
	o=`ls $adir/ | grep -v PbR | grep -v SRt | grep -v PbD | grep -v PSg | head -n 1`
    if [ "$o" != "" ] ; then
		echo $adir/$o
	fi
}

function getDicomValue()
{
	local theTag="$1"
	local theObj="$2"
    value=`$DCMTK_HOME/bin/dcmdump +P $theTag $theObj | sed 's;^.*\[\(.*\)\].*$;\1;'`
	echo "$value"
}

###############################################################################
# Main
###############################################################################

while getopts "t:v:m:n:h" OPT ; do
    case $OPT in
        t) proposedtag="$OPTARG" && checktag $proposedtag ;;
        v) value="$OPTARG" ;;
        m) MatchingFile="$OPTARG" ;;
        n) NonMatchingFile="$OPTARG" ;;
		h) usage && exit ;;
        *) echo "Unknown option or no option given"
           exit $E_OPTERROR
           ;;
    esac
done

tag="$proposedtag"

if [ "$tag" = "" ] ; then
	echo -e "\nERROR: No tag given.\n"
	usage
	exit
else
	echo -e "tag: $tag"
fi

if [ "$value" = "" ] ; then
	echo -e "\nERROR: No value given.\n"
	usage
	exit
else
	echo -e "value: $value"
fi

# get studies in archive database table
if [ ! -e "$STUDYLIST" ] ; then
	echo "$STUDYLIST does not exist.  Building it"
	echo "select STYIUID from Archive where ARCHST > 0 " | $MYSQL_HOME/bin/mysql -N imagemedical > $STUDYLIST
else
	echo "$STUDYLIST file exists.  Using it"
fi

total=`cat $STUDYLIST | wc -l`

echo -e "Total number of studies to search: $total"

# Loop through studies and check values
for s in `cat $STUDYLIST`
do
	obj=`getObject $s`
	if [ "$obj" != "" ] ; then
		#echo "$obj"
		thisobjValue=`getDicomValue $tag $obj`
		if [ "$thisobjValue" = "$value" ] ; then
			echo "$s" >> $MatchingFile
		else
			echo "$s: $thisobjValue !=  $value" >> $NonMatchingFile
		fi
	fi
done
