#!/bin/sh
#
# Component: tools
#
# Description:
#    Checks data/dicom, var/processed and var/cache directories for legacy study directories and convert them to hashed directories.
#
# Usage:
#
# checkLegacyStudies.sh [-v] [-f]
#
#    -v : print verbose messages
#    -f : move legacy directories to hashed directories
#
#  Lists legacy study directories left on the server. If the -f option is specified, then moves legacy
#  study directories to the hashed directories and create links to the hashed directories.
#
# Last Updated     : $Author: zsurmi $
# Update Date Time : $Date: 2015/04/14 08:12:57 $
# RCS File Name    : $RCSfile: checkLegacyStudies.sh,v $
# RCS Revision     : $Revision: 1.1 $
# Locked by        : $Locker:  $
# Symbolic name    : $Name:  $
# State            : $State: Exp $
#

. $HOME/etc/setenv.sh


#
# Prints usage information
#
# [$1] - error message to be printed
#
function usage_() {
	[ -n "$1" ] && echo "$1" >&2
	cat <<-EOFUSAGE
		checkLegacyStudies.sh [-v] [-f]

			-v : print verbose messages
			-f : move legacy directories to hashed directories

		  Lists legacy study directories left on the server. If the -f option is specified, then moves legacy
		  study directories to the hashed directories and create links to the hashed directories.
	EOFUSAGE

	exit 1
}


isVerbose="false"
fixStudies="false"

while getopts 'fvh' OPT; do
   case $OPT in
   f) fixStudies="true" ;;
   v) isVerbose="true" ;;
   h) usage_ ;;
   *) usage_ "Invalid_Parameter:$OPT" ;;
   esac
done



#
# Print verbose messages if verbose mode is turned on
#
# $1 - message to be printed
#
function verbose_() {
	[ "true" = "$isVerbose" ] && echo "$1"
}


#
# Checks legacy directory for legacy studies and tries to move them to the hashed directory.
#
# $1 - Legacy Directory
# $2 - Hashed Directory
#
function checkDirs_() {
	local legacyDir="$1"
	local hashedDir="$2"

	verbose_ "#  legacyDir: $legacyDir"
	verbose_ "#  hashedDir: $hashedDir"

	local study;
	for study in `ls $legacyDir`; do
		verbose_ "#   Checking $study"

		# Skip symbolic links
		if [ -h "$legacyDir/$study" ] ; then
			verbose_ "#    OK $study"
			continue
		fi

		verbose_ "#    Legacy Study: $study"
		hashedStudy=`$UTILS_HOME/bin/getHashDirectory -i "$study"`
		if [ -e "$hashedDir/$hashedStudy" ] ; then
			echo "ERROR $study : Both $legacyDir/$study and $hashedDir/$hashedStudy exists"
			continue
		else
			echo "LEGACY $study $legacyDir"
		fi

		if [ "true" = "$fixStudies" ] ; then
			verbose_ "#    fixing ..."
			hashDir=`dirname "$hashedDir/$hashedStudy"`
			verbose_ "mkdir -p $hashDir"
			mkdir -p "$hashDir" 2>/dev/null
			if [ ! -d "$hashDir" ] ; then
				echo "ERROR $study : Hashed directory ($hashDir) could not be created"
				continue
			fi

			verbose_ "mv $legacyDir/$study $hashedDir/$hashedStudy"
			mv "$legacyDir/$study" "$hashedDir/$hashedStudy"
			if [ $? -ne 0 ] ; then
				echo "ERROR $study : Study directory could not be moved to hashed directory ($legacyDir/$study to $hashedDir/$hashedStudy)"
				continue
			fi

			verbose_ "ln -s $hashedDir/$hashedStudy $legacyDir/$study"
			ln -s "$hashedDir/$hashedStudy" "$legacyDir/$study"
			if [ $? -ne 0 ] ; then
				echo "ERROR $study : Legacy link could not be created ($legacyDir/$study -> $hashedDir/$hashedStudy)"
			fi
		fi
	done
}


verbose_ "# checking studies in $DICOM_DATA"
checkDirs_ "$DICOM_DATA" "$HASHED_DICOM_DATA"


verbose_ "# checking studies in $PROCESSED"
checkDirs_ "$PROCESSED" "$HASHED_PROCESSED"


verbose_ "# checking studies in $CACHE"
checkDirs_ "$CACHE" "$HASHED_CACHE"


